@@ -3,7 +3,7 @@ testthat::context("Evaluate")
 testthat::test_that("", {
   e <- new.env(parent = environment())
   fname <- system.file("Introduction.plain", package = "REPLesentR")
-  file.copy(fname, tfname <- tempfile(fileext = ".Rmd"))
+  file.copy(fname, tfname <- tempfile(fileext = ".plain"))
   slideDeck <- SlideDeck()$new(Read()$auto(tfname, quiet = TRUE))
   evaluate <- Evaluate(e, quiet = TRUE)
   evaluate$slideDeck(slideDeck)
